summary | shortlog | log | commit | commitdiff | tree
raw | patch | inline | side by side (parent: b7ceaee)
raw | patch | inline | side by side (parent: b7ceaee)
author | cajus <cajus@594d385d-05f5-0310-b6e9-bd551577e9d8> | |
Thu, 20 Apr 2006 10:47:43 +0000 (10:47 +0000) | ||
committer | cajus <cajus@594d385d-05f5-0310-b6e9-bd551577e9d8> | |
Thu, 20 Apr 2006 10:47:43 +0000 (10:47 +0000) |
git-svn-id: https://oss.gonicus.de/repositories/gosa/trunk@3068 594d385d-05f5-0310-b6e9-bd551577e9d8
html/index.php | patch | blob | history | |
plugins/admin/systems/class_workstationStartup.inc | patch | blob | history |
diff --git a/html/index.php b/html/index.php
index d50359b2e4e50f5df45e881714b04bdd458d7236..77404340400739526f78c3d742ceb680665d58af 100644 (file)
--- a/html/index.php
+++ b/html/index.php
$_SESSION['js']= FALSE;
}
/* Check if gosa.conf is accessable */
if (!is_readable(CONFIG_DIR."/gosa.conf")){
print_red(sprintf(_("GOsa configuration %s/gosa.conf is not readable. Aborted."), CONFIG_DIR));
echo $_SESSION['errors'];
/* Check for compile directory */
if (!(is_dir($smarty->compile_dir) && is_writable($smarty->compile_dir))){
- print_red(sprintf(_("Directory '%s' specified as compile directory is not accessable!"),
+ print_red(sprintf(_("Directory '%s' specified as compile directory is not accessible!"),
$smarty->compile_dir));
echo $_SESSION['errors'];
exit();
@@
$_SESSION['js']= FALSE;
}
-/* Check if gosa.conf is accessable */
+/* Check if gosa.conf is accessible */
if (!is_readable(CONFIG_DIR."/gosa.conf")){
print_red(sprintf(_("GOsa configuration %s/gosa.conf is not readable. Aborted."), CONFIG_DIR));
diff --git a/plugins/admin/systems/class_workstationStartup.inc b/plugins/admin/systems/class_workstationStartup.inc
index 45b041b559b0d918b7f8b9a5ca34c0edf6f91f1c..fc875774d89070a6af2c8e41bd0e4acaee059773 100644 (file)
var $gotoFilesystem = array();
var $gotoTerminalPath = "";
var $FAIstatus = "";
- var $gotoBootKernels = array("default" => "default");
+ var $gotoBootKernels = array();
/* attribute list for save action */
var $attributes = array("gotoLdapServer", "gotoBootKernel", "gotoKernelParameters", "FAIclass", "FAIstatus", "gotoShare","FAIdebianMirror", "FAIrelease");
$this->orig_dn= $this->dn;
+ /* Handle inheritance value "default" */
+ $this->gotoBootKernels= array("%default%" => '['._("inherited").']');
+
/* Get list of boot kernels */
if (isset($this->config->data['TABS'])){
$command= search_config($this->config->data['TABS'], get_class($this), "KERNELS");
}
/* Strip out 'default' values */
if ($this->attrs['gotoLdapServer'] == "default"){
- unset ($this->attrs['gotoLdapServer']);
+ $this->attrs['gotoLdapServer']= array();
+ }
+ if ($this->attrs['gotoBootKernel'] == "%default%"){
+ $this->attrs['gotoBootKernel']= array();
}
/* if mirror == none stop saving this attribute */